@@ -12,7 +12,7 @@ use Tags::HTML::Messages;
 
 Readonly::Array our @FORM_METHODS => qw(post get);
 
-our $VERSION = 0.08;
+our $VERSION = 0.09;
 
 # Constructor.
 sub new {
@@ -20,7 +20,8 @@ sub new {
 
 	# Create object.
 	my ($object_params_ar, $other_params_ar) = split_params(
-		['css_register', 'form_method', 'lang', 'text', 'width'], @params);
+		['css_register', 'form_method', 'lang', 'logo_image_url',
+		'text', 'width'], @params);
 	my $self = $class->SUPER::new(@{$other_params_ar});
 
 	# CSS style for register box.
@@ -32,6 +33,9 @@ sub new {
 	# Language.
 	$self->{'lang'} = 'eng';
 
+	# Logo.
+	$self->{'logo_image_url'} = undef;
+
 	# Language texts.
 	$self->{'text'} = {
 		'eng' => {
@@ -95,7 +99,21 @@ sub _process {
 		['b', 'legend'],
 		['d', $self->_text('register')],
 		['e', 'legend'],
+	);
 
+	if (defined $self->{'logo_image_url'}) {
+		$self->{'tags'}->put(
+			['b', 'div'],
+			['a', 'class', 'logo'],
+			['b', 'img'],
+			['a', 'src', $self->{'logo_image_url'}],
+			['a', 'alt', 'logo'],
+			['e', 'img'],
+			['e', 'div'],
+		);
+	}
+
+	$self->{'tags'}->put(
 		['b', 'p'],
 		['b', 'label'],
 		['a', 'for', $username_id],
@@ -288,6 +306,12 @@ Language in ISO 639-3 code.
 
 Default value is 'eng'.
 
+=item * C<logo_image_url>
+
+URL to logo image.
+
+Default value is undef.
+
 =item * C<tags>
 
 'Tags::Output' object.
@@ -548,12 +572,12 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
-© 2021-2024 Michal Josef Špaček
+© 2021-2025 Michal Josef Špaček
 
 BSD 2-Clause License
 
 =head1 VERSION
 
-0.08
+0.09
 
 =cut
